/**
 * Copyright (C) 2001-2002
 * - France Telecom R&D
 * - Laboratoire Logiciels, Systemes, Reseaux - UMR 5526, CNRS-INPG-UJF
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors:
 *
 */

package org.objectweb.perseus.pool.api;

/**
 * The interface <b>PoolMatchFactory</b> defines the object used by a Pool to
 * test if a given resource of a Pool matches with the hints passed with the
 * Pool getResource method. It also allows such a Pool to allocate a
 * PoolResource as needed, conforming to the passed hints. Finally the factory
 * is called when a resource is going to be destroyed.
 *
 * @author S.Chassande-Barrioz, P.Dechamboux
 */
public interface PoolMatchFactory {
	/**
	 * <b>createResource</b> creates a new PoolResource.
	 * @param hints	The "properties" that the created PoolResource should
	 *				conform to.
	 * @return		The created PoolResource.
	 */
	Object createResource(Object hints) throws PoolException;

    /**
     * <b>matchResource</b> tests if a given resource of a Pool matches with
	 * the hints passed with the Pool getResource method.
	 * @param resource	The PoolResource to test its matching with some
	 *				"properties" specified by hints.
	 * @param hints	The "properties" that the PoolResource specified by pr
	 *				should match.
	 * @return		<b>true</b> if the pr PoolResource matches the hints
	 *				"properties".
	 */
   	boolean matchResource(Object resource, Object hints);

	/**
	 * is called when a resource is going to be destroyed. This method permits
	 * to close physical resource for example.
	 *  
	 * @param resource to initialize.
	 */
	void destroyResource(Object resource);
}
